/////////////////////////////////////////////////////////////////////////////////////
// File:	stringfunc.h
// Author:	Walt Jones
// Email:	wjones@blarg.net
// Date:	8 August, 2000
// Project:	ResNet Autoreg v2.0
// Purpose:	Provides functions that format strings
/////////////////////////////////////////////////////////////////////////////////////

// Make sure this file is included only once
#if !defined( STRINGFUNC_H )
#define STRINGFUNC_H

#include <string>
#include <stdlib.h>
#include <math.h>

string itostr(const int &number, const int &base);
string ltostr(const long &number, const int &base);
void rmEndWhite(char str[]);
char *toUpperCase(const char str[]);
string toUpperCase(const string str);
char *toLowerCase(const char str[]);
string toLowerCase(const string str);
string replaceStr(const string &original, const string &toFind, const string &toReplace);
string convertSysType(const string &str);
string convertCreationType(const string &str);
string convertAccountType(const string &str);
string convertUserStatus(const string &str);
string convertIPUsage(const string &str);
string convertYesNo(const string &str);

string itostr(const int &number, const int &base)
{
	char tempChar[2];
	string strNum;
	int tempNum;
	
	if (number == 0)
		return "0";

	tempNum = abs(number);
	tempChar[1] = '\0';
	while (tempNum > 0)
	{
		tempChar[0] = char((tempNum%base) + 48);
		strNum = string(tempChar) + strNum;
		tempNum /= base;
	}
	
	delete tempChar;

	if (number < 0)
		return "-" + strNum;
	return strNum;
}

string ltostr(const long &number, const int &base)
{
	char tempChar[2];
	string strNum;
	long tempNum;
	
	if (number == 0)
		return "0";

	tempNum = abs(number);
	tempChar[1] = '\0';
	while (tempNum > 0)
	{
		tempChar[0] = char((tempNum%base) + 48);
		strNum = string(tempChar) + strNum;
		tempNum /= base;
	}
	delete tempChar;

	if (number < 0)
		return "-" + strNum;
	return strNum;
}

void rmEndWhite(char str[])
{
	int len = strlen(str)-1;
	int i;
	for (i=len; (str[i] == 32)&&(i >=0); i--);
	str[i+1] = '\0';
	return;
}

char *toUpperCase(const char str[])
{
	char *tempStr = new char[strlen(str)];
	strcpy(tempStr, str);
	for (int i=(strlen(tempStr)-1); i >= 0; i--)
		if ((tempStr[i] >= 97)&&(tempStr[i] <= 122))
			tempStr[i] = toupper(tempStr[i]);
	return tempStr;
}

string toUpperCase(const string str)
{
	return string(toUpperCase(str.c_str()));
}

char *toLowerCase(const char str[])
{
	char *tempStr = new char[strlen(str)];
	strcpy(tempStr, str);
	for (int i=(strlen(tempStr)-1); i >= 0; i--)
		if ((tempStr[i] >= 65)&&(tempStr[i] <= 90))
			tempStr[i] = tolower(tempStr[i]);
	return tempStr;
}

string toLowerCase(const string str)
{
	return string(toLowerCase(str.c_str()));
}

string replaceStr(const string &original, const string &toFind, const string &toReplace)
{
	string newStr = original;
	int i = newStr.find(toFind, 0);
	
	while (i != string::npos)
	{
		newStr = newStr.erase(i, toFind.length());
		newStr = newStr.insert(i, toReplace);
		i = newStr.find(toFind, i);
	}
	
	return newStr;
}

string convertSysType(const string &str)
{
	if (str == "T")
		return "Tower";
	else if (str == "L")
		return "Laptop";
	else if (str == "D")
		return "Desktop";
	return "";
}

string convertCreationType(const string &str)
{
	if (str == "A")
		return "Automatic";
	else if (str == "M")
		return "Manual";
	return "";
}

string convertAccountType(const string &str)
{
	if (str == "S")
		return "Single";
	else if (str == "M")
		return "Multiple";
	else if (str == "A")
		return "Administrative";
	return "";
}

string convertUserStatus(const string &str)
{
	if (str == "A")
		return "Active";
	else if (str == "I")
		return "Inactive";
	else if (str == "P")
		return "Pending";
	return "";
}

string convertIPUsage(const string &str)
{
	if (str == "C")
		return "Committed";
	else if (str == "F")
		return "Free";
	else if (str == "W")
		return "Wounded";
	else if (str == "A")
		return "Abandoned";
	else if (str == "O")
		return "Out of Service";
	return "";
}

string convertYesNo(const string &str)
{
	if (str == "Y")
		return "Yes";
	else if (str == "N")
		return "No";
	return "";
}

#endif // defined( STRINGFUNC_H )
